Stan Math Library: stan/math/rev/scal/fun/log_mix.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_mix.hpp File Reference
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/fun/log_mix.hpp>`
`#include <stan/math/rev/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/meta/is_constant_struct.hpp>`
`#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::log_mix_partial_helper (const double &theta_val, const double &lambda1_val, const double &lambda2_val, double &one_m_exp_lam2_m_lam1, double &one_m_t_prod_exp_lam2_m_lam1, double &one_d_t_plus_one_m_t_prod_exp_lam2_m_lam1)
template<typename T_theta , typename T_lambda1 , typename T_lambda2 >
return_type< T_theta, T_lambda1, T_lambda2 >::type | stan::math::log_mix (const T_theta &theta, const T_lambda1 &lambda1, const T_lambda2 &lambda2)
| Return the log mixture density with specified mixing proportion and log densities and its derivative at each. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.